@@ -6,26 +6,26 @@
 --
 -- $Id: redirecthandler.lua,v 1.11 2008/07/25 18:40:31 mascarenhas Exp $
 -------------------------------------------------------------------------------
-require "socket.url"
-require "xavante.httpd"
+local url = require "socket.url"
+local httpd = require "xavante.httpd"
 
-module ("xavante.redirecthandler", package.seeall)
+local _M = {}
 
 -- params = { dest, action }
 -- dest can be of three kinds:
---	absolute: begins with protocol string or '/', the entire path is replaced with dest
---	concat: begins with ':', dest is appended to the path
---	relative: dest is appended to the dirname of the path
+--      absolute: begins with protocol string or '/', the entire path is replaced with dest
+--      concat: begins with ':', dest is appended to the path
+--      relative: dest is appended to the dirname of the path
 -- if used with patternhandler, dest can use the captures with %1, %2 etc.
 -- action can be "redirect" or "rewrite", default is "rewrite", except when
 --      dest starts with a protocol string
 local function redirect (req, res, dest, action, cap)
   dest = string.gsub(dest, "%%(%d)", function (capn) return cap[tonumber(capn)] or "" end)
   dest = string.gsub(dest, "%%%%", "%")
-  
+
   local path = req.parsed_url.path
   local pfx = string.sub (dest, 1,1)
-  
+
   if pfx == "/" then
     path = dest
   elseif pfx == ":" then
@@ -37,14 +37,14 @@ local function redirect (req, res, dest, action, cap)
     path = string.gsub (path, "/[^/]*$", "") .. "/" .. dest
   end
 
-  local path, query = path:match("^([^?]+)(%??.*)$")  
+  local path, query = path:match("^([^?]+)(%??.*)$")
   req.parsed_url.path = path
-  req.built_url = socket.url.build (req.parsed_url) .. (query or "")
+  req.built_url = url.build (req.parsed_url) .. (query or "")
   req.cmd_url = string.gsub (req.built_url, "^[^:]+://[^/]+", "")
-  
+
   if action == "redirect" then
-    xavante.httpd.redirect(res, path .. (query or ""))
-    return res    
+    httpd.redirect(res, path .. (query or ""))
+    return res
   elseif type(action) == "function" then
     return action(req, res, cap)
   else
@@ -52,8 +52,10 @@ local function redirect (req, res, dest, action, cap)
   end
 end
 
-function makeHandler (params)
+function _M.makeHandler (params)
   return function (req, res, cap)
-	   return redirect (req, res, params[1], params[2], cap)
-	 end
+           return redirect (req, res, params[1], params[2], cap)
+         end
 end
+
+return _M
\ No newline at end of file
