@@ -7,9 +7,9 @@
 -- $Id: vhostshandler.lua,v 1.3 2007/08/20 22:20:44 carregal Exp $
 -----------------------------------------------------------------------------
 
-function xavante.vhostshandler (vhosts)
-	return function (req, res)
-		local h = vhosts [req.headers.host] or vhosts [""]
-		return h (req, res)
-	end
-end
+return function (vhosts)
+         return function (req, res)
+                  local h = vhosts [req.headers.host] or vhosts [""]
+                  return h (req, res)
+                end
+       end
